@@ -1,13 +1,13 @@
 package OpenInteract;
 
-# $Id: OpenInteract.pm,v 1.51 2003/08/14 22:32:47 lachoy Exp $
+# $Id: OpenInteract.pm,v 1.53 2004/05/30 15:13:49 lachoy Exp $
 
 use strict;
 use Apache::Constants qw( :common :remotehost :response );
 use Apache::Request;
 use Data::Dumper      qw( Dumper );
 
-$OpenInteract::VERSION  = '1.60';
+$OpenInteract::VERSION  = '1.61';
 
 # Generic separator used in display
 
@@ -464,19 +464,38 @@ sub run_content_handler {
 
 sub send_static_file {
     my ( $class, $R ) = @_;
-    my $fh = Apache->gensym;
-    eval { open( $fh, $R->{page}{send_file} ) || die $!; };
-    if ( $@ ) {
-        $R->scrib( 0, "Cannot open static file from filesystem ($R->{page}{send_file}): $@" );
-        return NOT_FOUND;
-    }
-    unless ( $R->{page}{send_file_size} ) {
-        $R->{page}{send_file_size} = (stat $R->{page}{send_file})[7];
-    }
-    $R->apache->headers_out->{'Content-Length'} = $R->{page}{send_file_size};
-    $R->DEBUG && $R->scrib( 1, "Sending file ($R->{page}{send_file}) of size",
-                               "($R->{page}{send_file_size}) and type",
+    my $fh = $R->{page}{send_file};
+    my ( $file_size );
+
+    # File is a handle...
+    if ( ref $fh ) {
+        my $default_type = 'application/octet-stream';
+        unless ( $R->{page}{content_type} ) {
+            $R->scrib( 0, "No content type set for filehandle to send, ",
+                          "using default '$default_type'\n" );
+            $R->{page}{content_type} = $default_type;
+        }
+        $file_size = (stat $fh)[7];
+        $R->DEBUG && $R->scrib( 1, "Sending filehandle of size",
+                               "($file_size) and type",
                                "($R->{page}{content_type})" );
+    }
+
+    # File is a filename...
+    else {
+        my $fh = Apache->gensym;
+        eval { open( $fh, $R->{page}{send_file} ) || die $!; };
+        if ( $@ ) {
+            $R->scrib( 0, "Cannot open static file from filesystem ($R->{page}{send_file}): $@" );
+            return NOT_FOUND;
+        }
+        $file_size = $R->{page}{send_file_size}
+                     || (stat $R->{page}{send_file})[7];
+        $R->DEBUG && $R->scrib( 1, "Sending file ($R->{page}{send_file}) of size",
+                                "($file_size) and type",
+                                "($R->{page}{content_type})" );
+    }
+    $R->apache->headers_out->{'Content-Length'} = $file_size;
     $R->apache->send_http_header( $R->{page}{content_type} );
     $R->apache->send_fd( $fh );
     close( $fh );
