@@ -4,7 +4,7 @@ package OpenInteract::ApacheStartup;
 
 use strict;
 use Apache;
-use Apache::DBI;
+#use Apache::DBI;
 use File::Path;
 use OpenInteract::DBI;
 use OpenInteract::Startup;
