@@ -1,6 +1,6 @@
 package OpenInteract::FullText;
 
-# $Id: FullText.pm,v 1.12 2002/01/02 02:43:56 lachoy Exp $
+# $Id: FullText.pm,v 1.13 2002/11/10 15:14:23 lachoy Exp $
 
 use strict;
 use Lingua::Stem ();
@@ -11,7 +11,7 @@ BEGIN {
     eval { require OpenInteract::FullTextIterator };
 }
 
-$OpenInteract::FullText::VERSION = sprintf("%d.%02d", q$Revision: 1.12 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::FullText::VERSION = sprintf("%d.%02d", q$Revision: 1.13 $ =~ /(\d+)\.(\d+)/);
 @OpenInteract::FullText::ISA     = ();
 
 use constant COLUMN_GROUP    => 'listing';
@@ -141,8 +141,8 @@ sub _fulltext_object_listing {
 ########################################
 
 
-# Add the various group checking/validating methods 
-# to the subclass and send it on up the line 
+# Add the various group checking/validating methods
+# to the subclass and send it on up the line
 
 sub ruleset_factory {
     my ( $class, $rs_table ) = @_;
@@ -166,7 +166,7 @@ sub reindex_object {
     $R->DEBUG && $R->scrib( 1, "Indexable text: ", $$indexable );
     my $wc = _tokenize( $self, $indexable );
     $R->DEBUG && $R->scrib( 1, "Found the following tokens:", Dumper( $wc ) );
- 
+
     # In the 'real world', we'd start a transaction here...
 
     my $remove_rv = remove_object_from_index( $self );
@@ -187,7 +187,7 @@ sub remove_object_from_index {
     my $R = OpenInteract::Request->instance;
     $R->DEBUG && $R->scrib( 1, "Trying to remove from index: ",
                                ref $self, " (", $self->id, ")" );
-    return eval { $self->db_delete({ table => $TABLE_NAME, 
+    return eval { $self->db_delete({ table => $TABLE_NAME,
                                      where => 'object_key = ?',
                                      value => [ $object_key ] }) };
 }
@@ -212,6 +212,12 @@ sub _indexable_object_text {
         $R->scrib( 0, "Cannot index object text -- no fields presented in config file." );
         return undef;
     }
+
+    my $pre_index_method = $self->CONFIG->{fulltext_field};
+    if ( $pre_index_method ) {
+        eval { $self->$pre_index_method() };
+    }
+
     my ( $indexable );
     foreach my $field ( @{ $field_list } ) {
         if ( ! ref $self->{ $field } ) {
@@ -369,8 +375,8 @@ sub _screen_results {
         # The '- 1' is in there to account for the frequency key in
         # the results
 
-        my $num_removed = map { delete $results->{ $_ } } 
-                          grep { ( scalar keys %{ $results->{ $_ } } ) - 1 < $num_terms } 
+        my $num_removed = map { delete $results->{ $_ } }
+                          grep { ( scalar keys %{ $results->{ $_ } } ) - 1 < $num_terms }
                           keys %{ $results };
         $R->DEBUG && $R->scrib( 1, "Removed ($num_removed) items from the list",
                                    "since they didn't match all the terms" );
@@ -383,8 +389,6 @@ sub _screen_results {
 
 __END__
 
-=pod
-
 =head1 NAME
 
 OpenInteract::FullText - Metadata layer for objects to implement simple full-text searching
@@ -518,6 +522,10 @@ B<_indexable_object_text()>
 Gets the text out of the object to index. Currently, we treat all text
 from the object as one big field.
 
+Note that if you have defined 'fulltext_pre_index_method' as a
+configuration item in your class it is called before indexing. This is
+useful if you have a method to fetch external data into your object.
+
 B<_tokenize( $text )>
 
 Breaks text down into tokens. This process is very simple. First we
@@ -579,9 +587,9 @@ values a hashref of stemmed terms with the number of ocurrences of
 each term as the value there. For instance, doing a search for
 'congress' and 'senate' might bring up:
 
-  $oid = { 'OpenInteract::News||44' => { congress => 2, 
+  $oid = { 'OpenInteract::News||44' => { congress => 2,
                                          senate => 3 },
-           'OpenInteract::BasicPage||/toolkit/congress' => { congress => 8, 
+           'OpenInteract::BasicPage||/toolkit/congress' => { congress => 8,
                                                              senate => 1 },
            ...
   };
