@@ -1,19 +1,20 @@
 package OpenInteract::Handler::LookupEdit;
 
-# $Id: LookupEdit.pm,v 1.7 2001/11/09 14:08:38 lachoy Exp $
+# $Id: LookupEdit.pm,v 1.10 2002/01/02 02:43:56 lachoy Exp $
 
 # See 'doc/lookup.pod' for description of the fields in the action
 # table we use.
 
 use strict;
 use OpenInteract::Handler::GenericDispatcher;
-use SPOPS::Secure qw( SEC_LEVEL_WRITE );
+use SPOPS::Secure qw( :level );
 
 @OpenInteract::Handler::LookupEdit::ISA     = qw( OpenInteract::Handler::GenericDispatcher );
-$OpenInteract::Handler::LookupEdit::VERSION = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::LookupEdit::VERSION = sprintf("%d.%02d", q$Revision: 1.10 $ =~ /(\d+)\.(\d+)/);
 
-use constant DEFAULT_METHOD  => 'list_lookups';
-use constant DEFAULT_DISPLAY => 'column';
+use constant REQUIRED_SECURITY => SEC_LEVEL_WRITE;
+use constant DEFAULT_METHOD    => 'list_lookups';
+use constant DEFAULT_DISPLAY   => 'column';
 
 my $BLANK_COUNT = 5;
 my $NEW_KEY     = '_new_';
@@ -27,14 +28,18 @@ my $REMOVE_KEY  = '_remove_';
 sub handler {
     my ( $class, $p ) = @_;
     my $R = OpenInteract::Request->instance;
-    my $task = lc shift @{ $R->{path}->{current} } || DEFAULT_METHOD;
-    my $level = $R->user->check_security({ class     => $class,
-                                           object_id => '0' });
-    if ( $level < SEC_LEVEL_WRITE ) {
+    my $task = lc shift @{ $R->{path}{current} } || DEFAULT_METHOD;
+
+    # Just use 'security_object' here because we know it will hit the
+    # right database
+
+    my $level = $R->security_object->check_security({ class     => $class,
+                                                      object_id => '0' });
+    if ( $level < REQUIRED_SECURITY ) {
         $R->throw({ code  => 305,
                     type  => 'security',
                     extra => { user_level     => $level,
-                               required_level => SEC_LEVEL_WRITE,
+                               required_level => REQUIRED_SECURITY,
                                class          => $class,
                                task           => $task } });
     }
@@ -48,9 +53,10 @@ sub list_lookups {
     my ( $class, $p ) = @_;
     my $R = OpenInteract::Request->instance;
     $R->{page}{title} = 'List Available Lookups';
-    return $R->template->handler({}, { lookup_list => $class->_find_all_lookups,
-                                       status_msg  => $p->{status_msg},
-                                       error_msg   => $p->{error_msg} },
+    return $R->template->handler({},
+                                 { lookup_list => $class->_find_all_lookups,
+                                   status_msg  => $p->{status_msg},
+                                   error_msg   => $p->{error_msg} },
                                  { name => 'lookup::lookup_classes' });
 }
 
@@ -122,21 +128,30 @@ sub listing {
                                    $params{partition_field};
     }
 
-    $params{lookup_list} = $class->_lookup_entries( $lookup_info,
-                                                    $params{partition_value} );
+    $params{lookup_list} = eval {  $class->_lookup_entries( $lookup_info,
+                                                            $params{partition_value} ) };
+    if ( $@ ) {
+        $params{error_msg} = "Error retrieved when trying to lookup entries: $@";
+    }
+    else {
 
-    # Check to see if the lookup action has defined a set of related
-    # objects -- that is, the user when editing the lookup values
-    # should choose one from many values.
+        # Check to see if the lookup action has defined a set of related
+        # objects -- that is, the user when editing the lookup values
+        # should choose one from many values.
 
-    $lookup_info->{relate} ||= {};
-    foreach my $field_name ( keys %{ $lookup_info->{relate} } ) {
-        my $relate_info = $lookup_info->{relate}{ $field_name };
-        next if ( $params{related}->{ $field_name } );
-        $params{related}->{ $field_name } = $relate_info;
-        $params{related}->{ $field_name }{list} = $class->_lookup_related_objects(
-                                                              $relate_info->{object},
-                                                              $relate_info );
+        $lookup_info->{relate} ||= {};
+        foreach my $field_name ( keys %{ $lookup_info->{relate} } ) {
+            my $relate_info = $lookup_info->{relate}{ $field_name };
+            next if ( $params{related}{ $field_name } );
+            $params{related}{ $field_name } = $relate_info;
+            $params{related}{ $field_name }{list} =
+                                        eval { $class->_lookup_related_objects(
+                                                                  $relate_info->{object},
+                                                                  $relate_info ) };
+            if ( $@ ) {
+                $params{error_msg} .= "<br>Cannot lookup related $field_name: $@";
+            }
+        }
     }
 
     my $display_type = $R->apache->param( 'display_type' ) || DEFAULT_DISPLAY;
@@ -162,14 +177,17 @@ sub edit {
     my @id_list      = $class->_retrieve_id_list( $apr, $lookup_info->{field_list}->[0] );
     my @new_id_list  = map { "$NEW_KEY$_" } ( 1 .. $BLANK_COUNT );
     my @save_params  = ( $apr, $lookup_class, $lookup_info->{field_list} );
+    my @error = ();
     foreach my $id ( @id_list, @new_id_list ) {
         $R->DEBUG && $R->scrib( 1, "Trying to find values for ID ($id)" );
-        eval { $class->_fetch_and_save( @save_params, $id ) };
+        eval { $class->_persist( @save_params, $id ) };
         if ( $@ ) {
-            $R->scrib( 0, "Cannot save ID ($id): ($@) $SPOPS::Error::system_msg" );
+            $R->scrib( 0, "Cannot save ID ($id): $SPOPS::Error::system_msg" );
+            push @error, "Error saving ($id): $SPOPS::Error::system_msg";
         }
     }
     return $class->list_lookups({
+              error_msg  => join( "<br>\n", @error ),
               status_msg => "Entries for $lookup_type entered successfully" });
 }
 
@@ -229,7 +247,7 @@ sub _find_lookup_info {
         return ( undef, "Cannot list lookup entries: ($lookup_type) is not a valid lookup." );
     }
     $lookup_info->{lookup_type} = $lookup_type;
-    return $lookup_info;
+    return ( $lookup_info, undef );
 
 }
 
@@ -248,19 +266,24 @@ sub _lookup_entries {
         $args{where} = "$lookup_info->{partition_field} = ?";
         $args{value} = [ $partition_value ];
     }
-    return $lookup_class->fetch_group( \%args );
+    my $listing = eval { $lookup_class->fetch_group( \%args ) };
+    if ( $@ ) {
+        die "$SPOPS::Error::system_msg\n";
+    }
+    return $listing;
 }
 
 
 sub _lookup_related_objects {
     my ( $class, $object_type, $params ) = @_;
     my $R = OpenInteract::Request->instance;
-    return $R->$object_type()->fetch_group({ order => $params->{order} })
-
+    my $listing = eval { $R->$object_type()->fetch_group({ order => $params->{order} }) };
+    if ( $@ ) { die $SPOPS::Error::system_msg }
+    return $listing;
 }
 
 
-sub _fetch_and_save {
+sub _persist {
     my ( $class, $apr, $lookup_class, $field_list, $id ) = @_;
     my $R = OpenInteract::Request->instance;
     my $is_new = ( $id =~ /^$NEW_KEY/ );
@@ -294,3 +317,138 @@ sub _remove {
 
 
 1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+OpenInteract::LookupEdit - Edit many simple objects at once
+
+=head1 SYNOPSIS
+
+ # See lookup/doc/lookup.pod for setup and usage
+
+=head1 DESCRIPTION
+
+This module implements generic lookup table editing. What this is and
+does is fully described in the package documentation, so check that out.
+
+Here we will only discuss the implementation.
+
+=head1 METHODS
+
+B<handler( \%params )>
+
+This method is called with every request of this action. We parse the
+URL and dispatch to the proper task, first checking to ensure that the
+security is correct. (Default security of C<SEC_LEVEL_WRITE> is
+required.)
+
+B<list_lookups( \%params )>
+
+Cycle through all the actions available and display the ones that are
+lookup actions. (Lookup actions have the property 'lookup' set the
+'yes'.
+
+B<partition_listing( \%params )>
+
+If the user has specified a lookup to be partitioned, then display a
+dropdown with the DISTINCT values of the C<partition_field> specified
+in the lookup action information.
+
+This is normally called from the C<listing> task (see below) when we
+encounter a request to list a partitioned lookup without a partition
+field value.
+
+B<listing( \%params )>
+
+List lookup objects in a form for editing. We also create blank
+entries so you can enter new lookup objects.
+
+B<edit( \%params )>
+
+Parse the form generated by the C<listing> task and for each create a
+new object, edit an exiting object, or remove an existing object
+depending on the user choice.
+
+=head2 Internal Methods
+
+B<_retrieve_id_list( $apache, $field_name )>
+
+Parses the submitted form to find all IDs submitted by a form. The
+exact C<$field_name> given does not matter, just as long as it is one
+of the fields being edited.
+
+B<_find_all_lookups()>
+
+Iterate through the available actions and find the lookup
+items.
+
+Returns a list of hashrefs, each hashref describing a lookup actions.
+
+B<find_distinct_values( $object_type, $distinct_field )>
+
+Find all unique instances of C<$distinct_field> in the table specified
+by C<$object_type>.
+
+Returns an arrayref of distinct values for C<$distinct_field>, sorted.
+
+B<_find_lookup_info( $action )>
+
+Retrieves information from the action table for C<$action>. If
+C<$action> is not a lookup, returns undef for the action information.
+
+Returns: two element list. The first item a hashref of action
+information, the second is a message.
+
+B<_lookup_entries( \%action_info [, $partition_value ] )>
+
+Run the query to retrieve the relevant information corresponding to
+C<\%action_info>. If C<$partition_value> is specified we filter the
+results by finding only records where the C<partition_field> key in
+C<\%action_info> is C<$partition_value>.
+
+B<_lookup_related_objects( $object_type, \%params )>
+
+Just run a query to retrieve all objects of type C<$object_type>. If
+the C<order> key in C<\%params> is specified we use it for sorting.
+
+B<_persist( $apache, $lookup_class, \@field_name, $id )>
+
+If the user has requested to remove the object, remove it.
+
+Returns: the results of an SPOPS C<remove()> call on the object.
+
+Otherwise, create the object with the new values and save it.
+
+Returns: The resulting C<$object>.
+
+B<_remove( $object )>
+
+Remove the object C<$object>. (Not much right now, but a hook for
+later.)
+
+=head1 BUGS
+
+None known.
+
+=head1 TO DO
+
+Nothing known.
+
+=head1 SEE ALSO
+
+=head1 COPYRIGHT
+
+Copyright (c) 2001-2002 intes.net, inc.. All rights reserved.
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
+=head1 AUTHORS
+
+Chris Winters <chris@cwinters.com>
+
+=cut
