@@ -1,6 +1,6 @@
 package OpenInteract::Handler::NewUser;
 
-# $Id: NewUser.pm,v 1.9 2002/11/25 14:02:23 lachoy Exp $
+# $Id: NewUser.pm,v 1.11 2003/04/07 02:46:09 lachoy Exp $
 
 use strict;
 use Data::Dumper  qw( Dumper );
@@ -8,7 +8,7 @@ use SPOPS::Secure qw( :level :scope );
 use SPOPS::Utility;
 
 @OpenInteract::Handler::NewUser::ISA     = qw( OpenInteract::Handler::GenericDispatcher );
-$OpenInteract::Handler::NewUser::VERSION = sprintf("%d.%02d", q$Revision: 1.9 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::NewUser::VERSION = sprintf("%d.%02d", q$Revision: 1.11 $ =~ /(\d+)\.(\d+)/);
 
 $OpenInteract::Handler::NewUser::author            = 'chris@cwinters.com';
 $OpenInteract::Handler::NewUser::default_method    = 'show';
@@ -113,8 +113,8 @@ sub edit {
 
     else {
         $new_user->log_action_enter( 'create',
-                                     $new_user->id,
-                                     $new_user->id );
+                                     scalar( $new_user->id ),
+                                     scalar( $new_user->id ) );
     }
 
     # If that worked ok, send the user an email with the password created
@@ -134,7 +134,7 @@ I hope you enjoy $R->{server_name}!
 
 The Management
 
-PS: Note that if you do not login within 24 hours your account will 
+PS: Note that if you do not login within 24 hours your account will
 be deleted. So hop to it!
 
 NOTIFY
@@ -145,10 +145,26 @@ NOTIFY
     if ( $@ ) {
         $R->scrib( 0, "Cannot send email! ", Dumper( OpenInteract::Error->get ) );
         $R->throw({ code => 203 });
-        return $class->show({ error_msg => "Could not send email to you with assigned password." });
+        my $msg = "Could not send email to you with assigned password.";
+        return $class->show({ error_msg => $msg });
+    }
+
+    my $action_info = $R->lookup_action( 'newuser',
+                                         { return => 'info' } );
+
+    # Note: this is tightly coupled to how we do things in OI::Auth.
+
+    if ( $action_info->{autologin} eq 'yes' ) {
+        $R->{page}{title} = 'Account Created!';
+        $R->{page}{return_url} = '/NewUser/';
+        $R->{auth}{user} = $new_user;
+        $R->{auth}{logged_in} = $new_user;
+        $R->{session}{user_id} = $new_user->id;
+    }
+    else {
+        $R->{page}{title} = 'Account Created! Now login.';
+        $R->{page}{return_url} = '/NewUser/';
     }
-    $R->{page}{title} = 'Account Created! Now login.';
-    $R->{page}{return_url} = '/NewUser/';
     return <<OK;
 <h2 align="center">E-Mail Sent</h2>
 <p>Your account information has been sent to <tt>$email</tt>. Follow
