@@ -1,6 +1,6 @@
 package OpenInteract::Handler::ObjectActivity;
 
-# $Id: ObjectActivity.pm,v 1.4 2002/05/05 16:45:05 lachoy Exp $
+# $Id: ObjectActivity.pm,v 1.5 2002/12/13 22:16:29 lachoy Exp $
 
 use strict;
 use OpenInteract::Handler::GenericDispatcher qw( DEFAULT_SECURITY_KEY );
@@ -9,7 +9,7 @@ use SPOPS::Secure qw( :level );
 @OpenInteract::Handler::ObjectActivity::ISA     = qw(
    OpenInteract::Handler::GenericDispatcher  SPOPS::Secure
 );
-$OpenInteract::Handler::ObjectActivity::VERSION           = sprintf("%d.%02d", q$Revision: 1.4 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::ObjectActivity::VERSION           = sprintf("%d.%02d", q$Revision: 1.5 $ =~ /(\d+)\.(\d+)/);
 $OpenInteract::Handler::ObjectActivity::author            = 'chris@cwinters.com';
 $OpenInteract::Handler::ObjectActivity::default_method    = 'search_form';
 @OpenInteract::Handler::ObjectActivity::forbidden_methods = ();
@@ -104,17 +104,6 @@ sub _set_object_info {
     foreach my $rec ( @{ $activity_list } ) {
         my %info = %{ $rec };
         my $object_class = $rec->{class};
-        my $object = eval { $object_class->fetch( $rec->{object_id} ) };
-        if ( $@ or ! $object ) {
-            $info{object_type} = 'unknown';
-            $info{title}       = 'n/a';
-        }
-        else {
-            my $object_info = $object->object_description;
-            $info{object_type} = $object_info->{name};
-            $info{title}       = $object_info->{title};
-            $info{display_url} = $object_info->{url};
-        }
 
         unless ( $user_cache{ $rec->{action_by} } ) {
             my $user = eval { $R->user->fetch( $rec->{action_by} ) };
@@ -129,6 +118,24 @@ sub _set_object_info {
             $info{login_name}       = $user->{title};
             $info{user_display_url} = $user->{url};
         }
+
+        $info{object_type} = $object_class->CONFIG->{object_name};
+
+        if ( $info{action} eq 'remove' ) {
+            $info{title} = $info{object_id};
+        }
+        else {
+            my $object = eval { $object_class->fetch( $rec->{object_id} ) };
+            if ( $@ or ! $object ) {
+                $info{title}       = 'n/a';
+            }
+            else {
+                my $object_info = $object->object_description;
+                $info{title}       = $object_info->{title};
+                $info{display_url} = $object_info->{url};
+            }
+        }
+
         push @new_activity, \%info;
     }
     return \@new_activity;
