@@ -1,6 +1,6 @@
 package OpenInteract::Handler::Page;
 
-# $Id: Page.pm,v 1.41 2003/04/08 16:49:59 lachoy Exp $
+# $Id: Page.pm,v 1.42 2003/05/18 20:08:57 lachoy Exp $
 
 use strict;
 use Class::Date ();
@@ -11,7 +11,7 @@ use OpenInteract::Handler::GenericDispatcher qw( DEFAULT_SECURITY_KEY );
 use SPOPS::Secure qw( :level );
 
 @OpenInteract::Handler::Page::ISA     = qw( OpenInteract::CommonHandler  SPOPS::Secure );
-$OpenInteract::Handler::Page::VERSION = sprintf("%d.%02d", q$Revision: 1.41 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::Page::VERSION = sprintf("%d.%02d", q$Revision: 1.42 $ =~ /(\d+)\.(\d+)/);
 $OpenInteract::Handler::Page::author            = 'chris@cwinters.com';
 $OpenInteract::Handler::Page::default_method    = 'show';
 @OpenInteract::Handler::Page::forbidden_methods = ();
@@ -576,9 +576,12 @@ sub show {
         $location = $class->_get_location( $p );
         my $item = eval { $R->page->page_by_location( $location ) };
         if ( $@ ) {
+            $R->scrib( 0, "Caught error when fetching page by location [$location]: $@" );
             $class->_fail_page_fetch( $location, $@ );
         }
         if ( $item and $item->isa( $R->page_directory ) ) {
+            $R->scrib( 1, "Returned item for location [$location] is a ",
+                          "page_directory object; run dir handler" );
             return $class->_run_directory_handler( $item, $location, $p );
         }
         $page = $item;
@@ -651,6 +654,7 @@ sub show_displayable_page {
     my $display_content = $class->_split_pages( $page );
 
     return $display_content if ( $page->{template_parse} eq 'no' );
+    $p->{page} = $page;
     return $R->template->handler( {}, $p, { text => \$display_content } );
 }
 
