@@ -1,19 +1,17 @@
 package OpenInteract::Handler::SystemBoxes;
 
-# $Id: SystemBoxes.pm,v 1.11 2002/01/23 17:23:14 lachoy Exp $
+# $Id: SystemBoxes.pm,v 1.12 2002/08/25 00:07:09 lachoy Exp $
 
 use strict;
 use SPOPS::Secure qw( :level );
 
-@OpenInteract::Handler::SystemBoxes::ISA     = qw();
-$OpenInteract::Handler::SystemBoxes::VERSION = sprintf("%d.%02d", q$Revision: 1.11 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::SystemBoxes::VERSION = substr(q$Revision: 1.12 $, 10);
 
 $OpenInteract::Handler::SystemBoxes::author            = 'chris@cwinters.com';
 $OpenInteract::Handler::SystemBoxes::default_method    = 'handler';
 @OpenInteract::Handler::SystemBoxes::forbidden_methods = ();
 %OpenInteract::Handler::SystemBoxes::security = (
  handler        => SEC_LEVEL_NONE,
- templates_used => SEC_LEVEL_READ
 );
 
 my @BOX_KEYS = qw( name weight title template package class method code );
@@ -32,13 +30,6 @@ my %ADMIN_BOX_DEFAULTS = (
        title    => 'Admin Tools',
        name     => 'admin_tools_box' );
 
-my %TEMPLATES_USED_BOX_DEFAULTS = (
-       class    => 'OpenInteract::Handler::SystemBoxes',
-       method   => 'templates_used',
-       weight   => 11,
-       title    => 'Templates Used',
-       name     => 'templates_used_box' );
-
 my %LOGIN_BOX_DEFAULTS = (
        template => 'login_box',
        package  => 'base_box',
@@ -64,7 +55,7 @@ sub handler {
                                            params   => { user => $R->{auth}{user} } });
 
         # Now, if the user is a member of the site admin group, add the
-        # 'Admin Tools' box and the 'Templates Used' box.
+        # 'Admin Tools' box
 
         my $site_admin_id = $conf->{default_objects}{site_admin_group};
         my $supergroup_id = $conf->{default_objects}{supergroup};
@@ -75,9 +66,6 @@ sub handler {
             push @{ $R->{boxes} }, $class->_assign_params({
                                              action   => 'admin_tools_box',
                                              defaults => \%ADMIN_BOX_DEFAULTS });
-            push @{ $R->{boxes} }, $class->_assign_params({
-                                             action   => 'templates_used_box',
-                                             defaults => \%TEMPLATES_USED_BOX_DEFAULTS });
             last;
         }
         return undef;
@@ -109,46 +97,10 @@ sub _assign_params {
 }
 
 
-# Simple handler to put the list of templates used into a more
-# manageable form -- note that we can handle template objects and
-# 'package::name' strings in \@{ $R->{templates_used} }
-
-sub templates_used {
-    my ( $class ) = @_;
-    my $R = OpenInteract::Request->instance;
-    my %tmpl_by_package = ();
-    my %tmpl_used = ();
-    foreach my $template ( @{ $R->{templates_used} } ) {
-        my ( $package, $name, $template_id, $full_name );
-        if ( ref $template ) {
-            ( $package, $name ) = ( $template->{package}, $template->{name} );
-            $template_id = $template->{template_id};
-        }
-        else {
-            ( $package, $name ) = $R->site_template->parse_name( $template );
-            if ( $package and ! $name ) {
-                $name    = $package;
-                $package = '(site)';
-            }
-            $full_name = $template;
-        }
-        next if ( $tmpl_used{ $package }{ $name } );
-        $tmpl_used{ $package }{ $name }++;
-        push @{ $tmpl_by_package{ $package } },
-                            { name      => $name,
-                              id        => $template_id,
-                              full_name => $full_name };
-    }
-    return $R->template->handler( {}, { templates_used => \%tmpl_by_package },
-                                  { name => 'base_box::templates_used_box' } );
-}
-
 1;
 
 __END__
 
-=pod
-
 =head1 NAME
 
 OpenInteract::Handler::SystemBoxes -- Generate default boxes that appear on all pages
@@ -190,11 +142,6 @@ B<admin_tools> (if in 'site admin' group)
 
 Displays links for site administrators.
 
-B<templates_used> (if in 'site admin' group)
-
-Displays a listing of the templates used for a request along with
-links so you can quickly jump to one and edit it.
-
 =head1 CONFIGURING BOXES
 
 Since each box is a component and components are defined through the
@@ -269,5 +216,3 @@ it under the same terms as Perl itself.
 =head1 AUTHORS
 
 Chris Winters <chris@cwinters.com>
-
-=cut
