@@ -1,13 +1,14 @@
 package OpenInteract::PageScan;
 
-# $Id: PageScan.pm,v 1.5 2002/01/21 20:34:11 lachoy Exp $
+# $Id: PageScan.pm,v 1.6 2003/08/13 02:10:08 lachoy Exp $
 
 use strict;
 use Class::Date qw();
 use File::Find  qw();
+use File::Spec;
 use base qw( Class::Accessor );
 
-$OpenInteract::PageScan::VERSION = sprintf("%d.%02d", q$Revision: 1.5 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::PageScan::VERSION = sprintf("%d.%02d", q$Revision: 1.6 $ =~ /(\d+)\.(\d+)/);
 
 use constant DEFAULT_EXPIRES_IN => 365;
 use constant DEFAULT_MIME_TYPE  => 'text/html';
@@ -181,7 +182,7 @@ sub get_file_info {
 sub absolute_filesystem_root {
     my ( $self ) = @_;
     return $self->html_root  unless ( $self->file_root );
-    return join( '/', $self->html_root, $self->file_root );
+    return File::Spec->catfile( $self->html_root, $self->file_root );
 }
 
 
@@ -190,7 +191,7 @@ sub absolute_filesystem_root {
 sub absolute_filesystem_location {
     my ( $self, $location ) = @_;
     $location =~ s|^/||;
-    return join( '/', $self->absolute_filesystem_root, $location );
+    return File::Spec->catfile( $self->absolute_filesystem_root, $location );
 }
 
 
@@ -263,8 +264,6 @@ sub descend {
 
 __END__
 
-=pod
-
 =head1 NAME
 
 OpenInteract::PageScan - Find new files in the html tree and create objects from them
@@ -273,12 +272,12 @@ OpenInteract::PageScan - Find new files in the html tree and create objects from
 
  # Note: You need to ensure that OpenInteract::Request has been
  # created beforehand.
-
+ 
  # Scan all the root HTML directory for new files, and add them if
  # found (using default info)
-
+ 
  use OpenInteract::PageScan;
-
+ 
  my $scanner = OpenInteract::PageScan->new;
  my $new_files = $scanner->find_new_files;
  $scanner->add_location( $_ ) for ( @{ $new_files } );
@@ -496,6 +495,3 @@ it under the same terms as Perl itself.
 =head1 AUTHORS
 
 Chris Winters <chris@cwinters.com>
-
-=cut
-
