@@ -1,12 +1,12 @@
 package OpenInteract::Request;
 
-# $Id: Request.pm,v 1.15 2002/09/08 20:51:07 lachoy Exp $
+# $Id: Request.pm,v 1.16 2003/08/13 02:04:41 lachoy Exp $
 
 use strict;
 use base qw( Class::Singleton );
 use Data::Dumper qw( Dumper );
 
-$OpenInteract::Request::VERSION = sprintf("%d.%02d", q$Revision: 1.15 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Request::VERSION = sprintf("%d.%02d", q$Revision: 1.16 $ =~ /(\d+)\.(\d+)/);
 
 $OpenInteract::Request::DEBUG = 0;
 
@@ -293,7 +293,11 @@ sub finish_request {
 
     # Clear out all the content in the object
 
-    delete $self->{ $_ } for ( keys %{ $self } );
+    foreach my $key ( keys %{ $self } ) {
+        # warn "Cleaning up key '$key' from request...\n";
+        delete $self->{ $key };
+     }
+
 }
 
 1;
