@@ -1,13 +1,15 @@
 package OpenInteract::ResultsIterator;
 
-# $Id: ResultsIterator.pm,v 1.6 2001/10/11 03:17:27 lachoy Exp $
+# $Id: ResultsIterator.pm,v 1.8 2002/01/16 16:45:18 lachoy Exp $
 
 use strict;
 use Data::Dumper     qw( Dumper );
 use SPOPS::Iterator  qw( ITER_IS_DONE );
 
+use constant DEBUG => 0;
+
 @OpenInteract::ResultsIterator::ISA     = qw( SPOPS::Iterator );
-$OpenInteract::ResultsIterator::VERSION = sprintf("%d.%02d", q$Revision: 1.6 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::ResultsIterator::VERSION = sprintf("%d.%02d", q$Revision: 1.8 $ =~ /(\d+)\.(\d+)/);
 
 sub initialize {
     my ( $self, $p ) = @_;
@@ -31,14 +33,24 @@ sub fetch_object {
 
     return ITER_IS_DONE unless ( $object_class and $object_id );
 
-    my $obj = eval { $object_class->fetch( $object_id,
-                                           { skip_security => $self->{_SKIP_SECURITY} } ) };
+    DEBUG && warn( "Item [$self->{_SEARCH_COUNT}] trying [$object_class] [$object_id]" );
+    my $object = eval { $object_class->fetch( $object_id,
+                                              { skip_security => $self->{_SKIP_SECURITY} } ) };
+
     if ( $@ ) {
-        $self->{_SEARCH_RAW_COUNT}++;
-        return $self->fetch_object;
+        if ( ref $@ and $@->isa( 'SPOPS::Exception::Security' ) or
+             $SPOPS::Error::type eq 'security' ) {
+            DEBUG && warn( "Skip to next item, caught security exception: $@" );
+            $self->{_SEARCH_RAW_COUNT}++;
+            return $self->fetch_object;
+        }
+        DEBUG && warn( "Caught non-security exception: $@" );
     }
 
-    return ITER_IS_DONE unless ( $obj );
+    unless ( $object ) {
+        DEBUG && warn( "Iterator is depleted (no object fetched), notify parent" );
+        return ITER_IS_DONE;
+    }
 
     # Using min/max and haven't reached it yet
 
@@ -61,7 +73,7 @@ sub fetch_object {
         my $extra_info = $self->{_SEARCH_RESULTS}->[ $current_count ]->{extra};
         my $extra_count = 0;
         foreach my $name ( @{ $self->{_SEARCH_EXTRA_NAME} } ) {
-            $obj->{"tmp_$name"} = $extra_info->[ $extra_count ];
+            $object->{"tmp_$name"} = $extra_info->[ $extra_count ];
             $extra_count++;
         }
     }
@@ -69,7 +81,7 @@ sub fetch_object {
     $self->{_SEARCH_RAW_COUNT}++;
     $self->{_SEARCH_COUNT}++;
 
-    return ( $obj, $self->{_SEARCH_COUNT} );
+    return ( $object, $self->{_SEARCH_COUNT} );
 }
 
 1;
@@ -117,7 +129,7 @@ L<OpenInteract::SearchManage>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2001 intes.net, inc.. All rights reserved.
+Copyright (c) 2001-2002 intes.net, inc.. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
