@@ -1,23 +1,36 @@
 package OpenInteract::SQLInstall::Group;
 
-# $Id: Group.pm,v 1.5 2002/01/02 02:43:54 lachoy Exp $
+# $Id: Group.pm,v 1.9 2002/05/02 12:41:20 lachoy Exp $
 
 use strict;
 use vars qw( %HANDLERS );
+use base qw( OpenInteract::SQLInstall );
 use SPOPS::SQLInterface;
 
-@OpenInteract::SQLInstall::Group::ISA = qw( OpenInteract::SQLInstall );
-
 use constant DEBUG => 0;
 
+my @TABLES = ( 'sys_group.sql', 'sys_group_user.sql' );
+
 my %FILES = (
-    tables   => [ 'group_table.sql', 'link_table.sql' ],
-    security => [ 'install_security.dat' ],
+    tables        => \@TABLES,
+    tables_oracle => [ 'sys_group_oracle.sql', 'sys_group_user.sql',
+                       'sys_group_sequence.sql' ],
+    tables_pg     => [ @TABLES, 'sys_group_sequence.sql' ],
+    tables_ib     => [ 'sys_group_interbase.sql', 'sys_group_user.sql',
+                       'sys_group_generator.sql' ],
+    security      => [ 'install_security.dat' ],
 );
 
 %HANDLERS = (
     create_structure => { '_default_' => [ 'create_structure',
-                                           { table_file_list => $FILES{tables} } ] },
+                                           { table_file_list => $FILES{tables} } ],
+                          'Oracle'    => [ 'create_structure',
+                                           { table_file_list => $FILES{tables_oracle} } ],
+                          'Pg'        => [ 'create_structure',
+                                           { table_file_list => $FILES{tables_pg} } ],
+                          'InterBase' => [ 'create_structure',
+                                           { table_file_list => $FILES{tables_ib} } ],
+    },
     install_data     => { '_default_' => \&initial_group_data },
     install_security => { '_default_' => [ 'install_data',
                                            { data_file_list => $FILES{security} } ] },
@@ -105,36 +118,3 @@ sub create_link_groups {
 }
 
 1;
-
-__END__
-
-=pod
-
-=head1 NAME
-
-OpenInteract::SQLInstall::Group - SQL installer for the base_group package
-
-=head1 SYNOPSIS
-
- $ oi_manage install_sql --package=base_group
-
-=head1 DESCRIPTION
-
-=head1 BUGS
-
-=head1 TO DO
-
-=head1 SEE ALSO
-
-=head1 COPYRIGHT
-
-Copyright (c) 2001-2002 intes.net, inc.. All rights reserved.
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
-=head1 AUTHORS
-
-Chris Winters <chris@cwinters.com>
-
-=cut
