@@ -1,17 +1,20 @@
 package OpenInteract::SQLInstall::News;
 
-# $Id: News.pm,v 1.6 2002/05/02 12:42:26 lachoy Exp $
+# $Id: News.pm,v 1.7 2002/09/06 19:26:20 lachoy Exp $
 
 use strict;
 use vars qw( %HANDLERS );
 use base qw( OpenInteract::SQLInstall );
 
 my %files = (
-   tables        => [ 'news.sql' ],
-   tables_oracle => [ 'news_oracle.sql', 'news_sequence.sql' ],
-   tables_pg     => [ 'news.sql', 'news_sequence.sql' ],
-   tables_ib     => [ 'news_interbase.sql', 'news_generator.sql' ],
-   security      => [ 'install_security.dat' ],
+   tables        => [ 'news.sql', 'news_section.sql' ],
+   tables_oracle => [ 'news_oracle.sql', 'news_sequence.sql',
+                      'news_section_oracle', 'news_section_sequence.sql' ],
+   tables_pg     => [ 'news.sql', 'news_sequence.sql',
+                      'news_section.sql', 'news_section_sequence.sql' ],
+   tables_ib     => [ 'news_interbase.sql', 'news_generator.sql',
+                      'news_section.sql', 'news_section_generator.sql' ],
+   security      => [ 'install_security.dat', 'install_news_section.dat' ],
 );
 
 %HANDLERS = (
