@@ -1,12 +1,12 @@
 package OpenInteract::Security;
 
-# $Id: Security.pm,v 1.11 2001/09/14 03:34:31 lachoy Exp $
+# $Id: Security.pm,v 1.14 2002/01/02 02:43:55 lachoy Exp $
 
 use strict;
 use SPOPS::Secure qw( :all );
 use Data::Dumper  qw( Dumper );
 
-$OpenInteract::Security::VERSION = sprintf("%d.%02d", q$Revision: 1.11 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Security::VERSION = sprintf("%d.%02d", q$Revision: 1.14 $ =~ /(\d+)\.(\d+)/);
 
 
 # Pass in:
@@ -21,8 +21,11 @@ $OpenInteract::Security::VERSION = sprintf("%d.%02d", q$Revision: 1.11 $ =~ /(\d
 
 sub fetch_by_object {
     my ( $class, $item, $p ) = @_;
+    $p ||= {};
     my $R = OpenInteract::Request->instance;
-    my $object_id = $p->{oid} || $p->{object_id};
+    my ( $object_class, $object_id );
+
+    $object_id = $p->{oid} || $p->{object_id};
     unless ( $item or ( $p->{class} and defined $object_id ) ) {
         my $msg = 'Cannot check security';
         my $system_msg = 'No item passed into method to check!';
@@ -34,32 +37,18 @@ sub fetch_by_object {
         die $msg;
     }
 
-    my ( $obj_class, $oid ) = $class->_get_class_and_oid({
-                                          %{ $p },
-                                          object_id => $object_id,
-                                          item      => $item } );
-
-    my $where = 'class = ? AND object_id = ? AND ( scope = ?';
-    my @value = ( $obj_class, $oid, SEC_SCOPE_WORLD );
-
-    # Setup the group and user search clauses
-
-    my ( $group_where, $group_value ) = $class->_build_group_sql( $p );
-    if ( $group_where )             { $where .= " OR $group_where " }
-    if ( scalar @{ $group_value } ) { push @value, @{ $group_value } }
-
-    my ( $user_where, $user_value )   = $class->_build_user_sql( $p );
-    if ( $user_where )              { $where .= " OR $user_where  " }
-    if ( scalar @{ $user_value } )  { push @value, @{ $user_value } }
-
-    $where .= ')';
-    $R->DEBUG && $R->scrib( 2, "Searching clause: $where\n",
-                               "with values ", join( '//', @value ) );
-
-    # Fetch the objects
+    # Build the SQL statement and fetch the objects
 
+    ( $object_class, $object_id ) =
+                         $class->_get_class_and_oid({ %{ $p },
+                                                      object_id => $object_id,
+                                                      item      => $item });
+    my ( $table, $where, $value ) =
+                         $class->build_security_sql({ %{ $p },
+                                                      object_class => $object_class,
+                                                      object_id    => $object_id });
      my $sec_list = eval { $class->fetch_group({ where => $where,
-                                                value => \@value }) };
+                                                 value => $value }) };
     if ( $@ ) {
         $SPOPS::Error::user_msg = 'Cannot retrieve security settings';
         die $SPOPS::Error::user_msg;
@@ -90,6 +79,43 @@ ITEM:
 }
 
 
+
+sub build_security_sql {
+    my ( $class, $p  ) = @_;
+    $p ||= {};
+
+    my $R = OpenInteract::Request->instance;
+    my $table = $class->table_name;
+    my ( $where );
+    my @value = ();
+
+    $p->{type} ||= 'standalone';
+    if ( $p->{type} eq 'standalone' ) {
+        $where = "$table.class = ? AND $table.object_id = ? AND ( $table.scope = ? ";
+        @value = ( $p->{object_class}, $p->{object_id}, SEC_SCOPE_WORLD );
+    }
+    elsif ( $p->{type} eq 'link' ) {
+        $where = "$table.class = ? AND $table.object_id = $p->{link_field} AND ( $table.scope = ? ";
+        @value = ( $p->{object_class}, SEC_SCOPE_WORLD );
+    }
+
+    # Setup the group and user search clauses
+
+    my ( $group_where, $group_value ) = $class->_build_group_sql( $p );
+    if ( $group_where )             { $where .= " OR $group_where " }
+    if ( scalar @{ $group_value } ) { push @value, @{ $group_value } }
+
+    my ( $user_where, $user_value )   = $class->_build_user_sql( $p );
+    if ( $user_where )              { $where .= " OR $user_where  " }
+    if ( scalar @{ $user_value } )  { push @value, @{ $user_value } }
+
+    $where .= ')';
+    $R->DEBUG && $R->scrib( 2, "Searching clause: $where\n",
+                               "with values ", join( '//', @value ) );
+    return ( $table, $where, \@value );
+}
+
+
 # Setup the SQL for the groups passed in
 
 sub _build_group_sql {
@@ -106,10 +132,12 @@ sub _build_group_sql {
         return ( undef, [] );
     }
 
+    my $table = $class->table_name;
+
     # Include the overall group clause unless we specified we want
     # 'none' of the groups
 
-    my $where = ' ( scope = ? ';
+    my $where = " ( $table.scope = ? ";
     my @value = ( SEC_SCOPE_GROUP );
 
   # Only specify the actual groups we want if $p->{group} is either a
@@ -123,7 +151,7 @@ sub _build_group_sql {
             $where .= ' AND ( ';
             foreach my $group ( @{ $group_list } ) {
                 next if ( ! $group );
-                $where .= ' scope_id = ? OR ';
+                $where .= " $table.scope_id = ? OR ";
                 my $gid = ( ref $group ) ? $group->id : $group;
                 push @value, $gid;
             }
@@ -151,8 +179,9 @@ sub _build_user_sql {
     # routine should ensure that $p->{user} is a single user object or
     # user_id.
 
+    my $table = $class->table_name;
     my $uid = ( ref $p->{user} ) ? $p->{user}->id : $p->{user};
-    $where = ' ( scope = ? AND scope_id = ? )';
+    $where = " ( $table.scope = ? AND $table.scope_id = ? )";
     push @value, SEC_SCOPE_USER, $uid;
 
     $R->DEBUG && $R->scrib( 3, "User WHERE clause: { $where }" );
@@ -364,7 +393,7 @@ None known.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2001 intes.net, inc.. All rights reserved.
+Copyright (c) 2001-2002 intes.net, inc.. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
