@@ -1,6 +1,6 @@
 package OpenInteract::Template::Plugin;
 
-# $Id: Plugin.pm,v 1.30 2003/03/25 16:28:12 lachoy Exp $
+# $Id: Plugin.pm,v 1.32 2003/08/13 12:28:43 lachoy Exp $
 
 use strict;
 use base qw( Template::Plugin );
@@ -11,7 +11,7 @@ use SPOPS::Secure   qw( :level :scope );
 use SPOPS::Utility;
 use Text::Sentence;
 
-$OpenInteract::Template::Plugin::VERSION  = sprintf("%d.%02d", q$Revision: 1.30 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Template::Plugin::VERSION  = sprintf("%d.%02d", q$Revision: 1.32 $ =~ /(\d+)\.(\d+)/);
 
 my %SECURITY_CONSTANTS  = (
   level => {
@@ -403,7 +403,9 @@ sub is_admin {
 
 sub return_url {
     my $R = OpenInteract::Request->instance;
-    return $R->{page}{return_url} ||  $R->{path}{original};
+    return $R->{page}{return_url}
+           || $R->{path}{login_fail}
+           || $R->{path}{original};
 }
 
 
@@ -418,6 +420,48 @@ sub theme {
     return theme_properties( @_ );
 }
 
+sub theme_fetch {
+    my ( $self, $theme_spec, $params ) = @_;
+    my ( $theme_id );
+    my $R = OpenInteract::Request->instance;
+    if ( $theme_spec =~ /^[\d\s]+$/ ) {
+        $theme_id = $theme_spec;
+    }
+    else {
+        $theme_id = $R->CONFIG->{default_objects}{ $theme_spec };
+    }
+    unless ( $theme_id ) {
+        $R->scrib( 0, "Could not fetch theme given spec of '$theme_spec': ",
+                      "it doesn't look like an object ID and no matching ",
+                      "no matching name found in 'default_objects' server ",
+                      "configuration" );
+
+        # Don't return undef or the caller will get a nasty surprise
+        # when he tries to use it
+
+        return $self->theme_properties;
+    }
+    my $new_theme = eval { $R->theme->fetch( $theme_id ) };
+    if ( $@ ) {
+        $R->scrib( 0, "Error fetching theme with ID '$theme_id': $@" );
+        return $self->theme_properties;
+    }
+    unless ( $new_theme ) {
+        $R->scrib( 0, "No theme with ID '$theme_id' exists" );
+        return $self->theme_properties;
+    }
+
+    # New theme looks good, fill it up...
+    my $new_props = $new_theme->all_values;
+
+    # ... and set for rest of request if specified
+    if ( $params->{set_for_request} eq 'yes' ) {
+        $R->{theme} = $new_theme;
+        $R->{theme_values} = $new_props;
+    }
+
+    return $new_props;
+}
 
 sub error_hold {
     return OpenInteract::Request->instance->{error_hold};
@@ -437,8 +481,6 @@ sub server_config {
 
 __END__
 
-=pod
-
 =head1 NAME
 
 OpenInteract::Template::Plugin - Custom OpenInteract functionality in templates
@@ -446,80 +488,83 @@ OpenInteract::Template::Plugin - Custom OpenInteract functionality in templates
 =head1 SYNOPSIS
 
  # Create the TT object with the OI plugin
-
+ 
  my $template = Template->new(
                        PLUGINS => { OI => 'OpenInteract::Template::Plugin' }, ... );
  my ( $output );
  $template->process( 'package::template', \%params, \$output );
-
-
+ 
+ 
  # In the template (brief examples, see below for more)
-
+ 
  [% OI.show_all_actions.join( "\n" ) -%]
-
+ 
  [% OI.comp( 'error_display', error_msg = error_msg ) -%]
-
+ 
  [% OI.box_add( 'contact_tools_box', title  = 'Contact Tools',
                                      weight = 2 ) -%]
-
+ 
  [% object_info = OI.object_description( object ) %]
  This is a [% object_info.name %] object.
-
+ 
  Is the object in the class? 
     [% OI.class_isa( object, 'SPOPS::DBI' ) ? 'yes' : 'no' %]
-
+ 
  Today is [% OI.date_format( 'now', '%Y-%m-%e %l:%M %p' ) %] the
  [% OI.date_format( 'now', '%j' ) %] day of the year
-
+ 
  [% d = OI.date_into_object( object.updated_on ) -%]
  [% OI.comp( 'date_select', month_value  = d.month,
                             day_value    = d.day,
                             year_value   = d.year, blank = 1,
                             field_prefix = 'updated_on' ) -%]
-
+ 
  [% OI.limit_string( object.description, 30 ) %]
-
+ 
  var person_last_name = '[% OI.javascript_quote( person.last_name ) %]';
-
+ 
  [% matched = OI.regex_chunk( 'It was the best of times, it was the blurst of times.',
                               '(blurst.*)' ) %]
-
+ 
  [% OI.limit_sentences( news.news_item, 3 ) %]
-
+ 
  [% score = grade.score / test.total %]
  Your grade is: [% OI.percent_format( score ) %]
-
+ 
  You have [% OI.money_format( account.balance ) %] left to spend.
-
+ 
  Hello [% OI.uc_first( person.first_name ) %]
-
+ 
  <textarea name="news_item">[% OI.html_encode( news.news_item ) %]</textarea>
-
+ 
  Item: [% OI.html_decode( news.news_item ) %]
-
+ 
  [% edit_url = OI.make_url( base = '/User/show/', user_id = OI.login.user_id,
                             edit = 1, show_all = 'yes' ) %]
  <a href="[% edit_url %]">Edit your information</a>
-
+ 
  [% theme = OI.theme_properties %]
  Background color of page: [% theme.bgcolor %]
-
+ 
+ [% new_theme = OI.theme_fetch( 5 ) %]
+ Background color of page from other theme: [% new_theme.bgcolor %]
+ 
  [% IF OI.logged_in -%]
  Hello [% OI.login.full_name %]. 
    Your groups are: [% OI.login_group.join( ', ' ) -%]
  [% ELSE -%]
  You are not logged in.
  [% END -%]
-
+ 
  Your last search: [% OI.session.latest_search %]
-
+ 
  <a href="[% OI.return_url %]">Refresh</a>
-
+ 
  [% IF OI.error_hold.myapp.field_out_of_bounds %]
    The entry you made is out of bounds:
         [% OI.error_hold.myapp.field_out_of_bounds %]
  [% END %]
-
+ 
  [% IF object.tmp_security_level >= OI.security_level.write -%]
    you can edit this object!
  [% END %]
@@ -937,6 +982,28 @@ Example:
 
   [% OI.use_main_template( 'mypkg::main' ) -%]
 
+B<theme_fetch( $new_theme_spec, \%params )>
+
+Retrieves the properties for theme C<$new_theme_spec>, which can be an
+ID (normal) or a name listed in the 'default_objects' of your server
+configuration. If the latter we'll use the ID associated with that
+name.
+
+If the key C<set_for_request> is set to 'yes' in C<\%params> then this
+new theme will be used for the remainder of the request. This includes
+the main template along with all graphical elements.
+
+Returns: hashref with all properties of the given theme.
+
+Examples:
+
+ [% new_theme = OI.theme_fetch( 5 ) %]
+ Background color of page from other theme: [% new_theme.bgcolor %]
+ 
+ [% new_theme = OI.theme_fetch( 5, set_for_request = 'yes' ) %]
+ Background color of page from other theme: [% new_theme.bgcolor %]
+ Hey, the new theme is now set for the rest of the request!
+
 =head2 PROPERTIES
 
 B<theme_properties()>
@@ -952,6 +1019,10 @@ Example:
 The exact properties in the theme depend on the theme. See the
 'base_theme' package for more information.
 
+B<theme()>
+
+Alias for 'theme_properties'
+
 B<login()>
 
 The user object representing the user who is currently logged in.
@@ -1174,5 +1245,3 @@ it under the same terms as Perl itself.
 =head1 AUTHORS
 
 Chris Winters <chris@cwinters.com>
-
-=cut
