@@ -1,10 +1,10 @@
 package OpenInteract::UI::Main;
 
-# $Id: Main.pm,v 1.9 2002/11/25 04:09:06 lachoy Exp $
+# $Id: Main.pm,v 1.11 2003/08/13 03:16:44 lachoy Exp $
 
 use strict;
 
-$OpenInteract::UI::Main::VERSION = sprintf("%d.%02d", q$Revision: 1.9 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::UI::Main::VERSION = sprintf("%d.%02d", q$Revision: 1.11 $ =~ /(\d+)\.(\d+)/);
 
 sub handler {
     my ( $class ) = @_;
@@ -44,9 +44,11 @@ sub handler {
     }
 
     # Check to see if we're supposed to send back a file (no content
-    # to return)
+    # to return) or we're doing an HTTP redirect
 
-    return undef if ( $R->{page}{send_file} );
+    if ( $R->{page}{send_file} || $R->{page}{http_redirect} ) {
+        return undef;
+    }
 
     # Otherwise pick the template to wrap the content in
 
@@ -57,7 +59,8 @@ sub handler {
     $R->{main_template_vars} ||= {};
     return $R->template->handler( {},
                                   { %{ $R->{main_template_vars} },
-                                    page => $R->{page} },
+                                    page => $R->{page},
+                                    path => $R->{path}{original} },
                                   { name => $template_name } );
 }
 
