@@ -12,7 +12,7 @@ CREATE TABLE sys_error (
  session_id    varchar(32),
  browser       varchar(75),
  referer       varchar(150),
- error_time    datetime,
+ error_time    %%DATETIME%%,
  url           varchar(150),
  notes         text,
  primary key   ( error_id )
